@@ -295,17 +295,18 @@ class Font(object):
         font = self.get_ttfont()
         version = font.sfntVersion
         flavor = font.flavor
+        format = None
         if flavor in [self.FORMAT_WOFF, self.FORMAT_WOFF2] and not ignore_flavor:
-            return flavor
+            format = flavor
         elif version == 'OTTO' and 'CFF ' in font:
-            return self.FORMAT_OTF
+            format = self.FORMAT_OTF
         elif version == '\0\1\0\0':
-            return self.FORMAT_TTF
+            format = self.FORMAT_TTF
         elif version == 'wOFF':
-            return self.FORMAT_WOFF
+            format = self.FORMAT_WOFF
         elif version == 'wOF2':
-            return self.FORMAT_WOFF2
-        return None
+            format = self.FORMAT_WOFF2
+        return format
 
     @classmethod
     def _get_name_id(cls, key):
@@ -333,7 +334,7 @@ class Font(object):
         font = self.get_ttfont()
         name_id = self._get_name_id(key)
         name_table = font['name']
-        name = name_table.getName(name_id, 3, 1)
+        name = name_table.getName(name_id, 3, 1, 0x0409)
         return name.toUnicode() if name else None
 
     def get_names(self):
@@ -352,9 +353,10 @@ class Font(object):
         }
         return names
 
-    def get_script_by_character(self, char):
+    @classmethod
+    def get_script_by_character(cls, char):
         """
-        Gets the script by character.
+        Gets the script by character (even if not included in the font).
 
         :param char: The character
         :type char: str
@@ -362,11 +364,12 @@ class Font(object):
         :returns: The script by character.
         :rtype: dict
         """
-        return self.get_script_by_code(ord(char))
+        return cls.get_script_by_code(ord(char))
 
-    def get_script_by_code(self, code):
+    @classmethod
+    def get_script_by_code(cls, code):
         """
-        Gets the script by unicode code point.
+        Gets the script by unicode code point (even if not included in the font).
 
         :param code: The code
         :type code: int
@@ -381,16 +384,17 @@ class Font(object):
             'block': unicodedata.block(code),
         }
 
-    def get_scripts(self):
+    @classmethod
+    def get_scripts_by_characters(cls, chars):
         """
-        Gets the scripts supported by the font.
+        Gets the scripts by characters (even if not included in the font).
 
         :returns: The scripts.
         :rtype: list of dict
         """
         blocks_by_scripts_tags = {}
-        for char in self.get_characters():
-            script = self.get_script_by_code(char['code'])
+        for char in chars:
+            script = cls.get_script_by_code(char['code'])
             script_tag = script['tag']
             script_block = script['block']
             if script_tag not in blocks_by_scripts_tags:
@@ -407,6 +411,15 @@ class Font(object):
         ]
         return scripts
 
+    def get_scripts(self):
+        """
+        Gets the scripts supported by the font.
+
+        :returns: The scripts.
+        :rtype: list of dict
+        """
+        return self.get_scripts_by_characters(chars=self.get_characters())
+
     def get_style_flag(self, key):
         """
         Gets the style flag reading OS/2 and macStyle tables.
@@ -469,9 +482,9 @@ class Font(object):
                 'name': self._VARIABLE_AXES_BY_TAG.get(axis.axisTag, {}).get(
                     'name', axis.axisTag.title()
                 ),
-                'minValue': axis.minValue,
-                'maxValue': axis.maxValue,
-                'defaultValue': axis.defaultValue,
+                'min_value': axis.minValue,
+                'max_value': axis.maxValue,
+                'default_value': axis.defaultValue,
             }
             for axis in font['fvar'].axes
         ]
@@ -515,12 +528,11 @@ class Font(object):
         if not self.is_variable():
             return None
         font = self.get_ttfont()
-        nameTable = font['name']
+        name_table = font['name']
         return [
             {
                 'coordinates': instance.coordinates,
-                'postscriptName': nameTable.getDebugName(instance.postscriptNameID),
-                'subfamilyName': nameTable.getDebugName(instance.subfamilyNameID),
+                'style_name': name_table.getDebugName(instance.subfamilyNameID),
             }
             for instance in font['fvar'].instances
         ]
@@ -617,7 +629,9 @@ class Font(object):
 
     def rename(self, family_name='', style_name=''):
         """
-        Renames the font names records according to the given family_name and style_name (subfamily_name).
+        Renames the font names records (1, 2, 4, 6, 16, 17) according to
+        the given family_name and style_name (subfamily_name).
+
         If family_name is not defined it will be auto-detected.
         If style_name is not defined it will be auto-detected.
 
@@ -625,6 +639,8 @@ class Font(object):
         :type family_name: str
         :param style_name: The style name
         :type style_name: str
+
+        :raises ValueError: if the computed PostScript-name is longer than 63 characters.
         """
         family_name = (
             family_name
@@ -640,6 +656,12 @@ class Font(object):
         postscript_family_name = family_name.replace(' ', '')
         postscript_subfamily_name = style_name.replace(' ', '')
         postscript_name = f'{postscript_family_name}-{postscript_subfamily_name}'
+        postscript_name_length = len(postscript_name)
+        if postscript_name_length > 63:
+            raise ValueError(
+                'PostScript name max-length (63 characters) exceeded'
+                f' ({postscript_name_length} characters).'
+            )
         names = {
             self.NAME_FAMILY_NAME: family_name,
             self.NAME_SUBFAMILY_NAME: style_name,
@@ -749,7 +771,8 @@ class Font(object):
         font = self.get_ttfont()
         name_id = self._get_name_id(key)
         name_table = font['name']
-        name_table.setName(value, name_id, 3, 1, None)
+        # https://github.com/fonttools/fonttools/blob/main/Lib/fontTools/ttLib/tables/_n_a_m_e.py#L568
+        name_table.setName(value, name_id, 3, 1, 0x0409)
 
     def set_names(self, names):
         """
@@ -844,10 +867,9 @@ class Font(object):
             )
         if isinstance(unicodes, (list, set, tuple)):
             unicodes = ', '.join(list(unicodes))
-        dash = '-'
-        mdash = '—'
-        minus = '−'
-        unicodes = unicodes.replace(mdash, dash).replace(minus, dash)
+        # replace possible — ‐ − (&mdash; &dash; &minus;) with -
+        for s in ('—', '‐', '−'):
+            unicodes = unicodes.replace(s, '-')
         unicodes = parse_unicodes(unicodes)
         # print(unicodes)
         subs_args = {'unicodes': unicodes, 'glyphs': glyphs, 'text': text}
@@ -905,8 +927,8 @@ class Font(object):
                 axis_value = tuple(axis_value)
             elif isinstance(axis_value, dict):
                 axis = self.get_variable_axis_by_tag(axis_tag)
-                axis_min = axis_value.get('min', axis.get('minValue'))
-                axis_max = axis_value.get('max', axis.get('maxValue'))
+                axis_min = axis_value.get('min', axis.get('min_value'))
+                axis_max = axis_value.get('max', axis.get('max_value'))
                 axis_value = (axis_min, axis_max)
             coordinates[axis_tag] = axis_value
 
@@ -974,4 +996,4 @@ class Font(object):
         :returns: String representation of the object.
         :rtype: str
         """
-        return f'Font("{self._filepath}")'
+        return f'Font(\'{self._filepath}\')'
